# @configu/py

## Install

> pip install configu

## CONTRIBUTING

### Requirements

1. Follow the instructions on the main [CONTRIBUTING.md](../CONTRIBUTING.md) to set up node and npm
2. Install [pyenv](https://github.com/pyenv/pyenv)
3. Install [poetry](https://python-poetry.org/)

### Setup

> Make sure you're in configu/py directory

1. Run `pyenv install` - take note of the version being installed. eg. 3.9.16
2. Run `pyenv shell {{INSTALLED_VERSAION}}` eg. `pyenv shell 3.9.16`
3. Run `poetry env use python`
4. Run `poetry install`
